==> jc-1.4.0.tar.gz: gnu/java/security/provider/Gnu__241.h <==
// final class gnu.java.security.provider.Gnu$1

// class file dependencies
// @dep_class f0178e05dba8a608 gnu_java_security_provider_Gnu__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_Gnu__241_H_
#define _JC_gnu_java_security_provider_Gnu__241_H_

// Forward structure declarations
struct _jc_gnu_java_security_provider_Gnu$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_Gnu__241$sub_refs	_jc_gnu_java_security_provider_Gnu__241$sub_refs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs	_jc_gnu_java_security_provider_Gnu__241$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$refs	_jc_gnu_java_security_provider_Gnu__241$refs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$nonrefs	_jc_gnu_java_security_provider_Gnu__241$nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$object	_jc_gnu_java_security_provider_Gnu__241$object;

typedef const struct _jc_gnu_java_security_provider_Gnu__241$vmethods	_jc_gnu_java_security_provider_Gnu__241$vmethods;
typedef const struct _jc_gnu_java_security_provider_Gnu__241$vtable	_jc_gnu_java_security_provider_Gnu__241$vtable;
typedef const struct _jc_gnu_java_security_provider_Gnu__241$vtype	_jc_gnu_java_security_provider_Gnu__241$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_Gnu__241$method$_init$0939e4b1125759da(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *, struct _jc_gnu_java_security_provider_Gnu$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_provider_Gnu__241$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_Gnu__241$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_security_provider_Gnu__241$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_Gnu__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_Gnu__241$vmethods	gnu_java_security_provider_Gnu__241;
};

// Vtype
struct _jc_gnu_java_security_provider_Gnu__241$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_Gnu__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu__241$sub_refs {
	struct _jc_gnu_java_security_provider_Gnu$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu__241$refs {
    _jc_gnu_java_security_provider_Gnu__241$sub_refs	gnu_java_security_provider_Gnu__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs	gnu_java_security_provider_Gnu__241;
};

// Object instance structure
struct _jc_gnu_java_security_provider_Gnu__241$object {
	_jc_gnu_java_security_provider_Gnu__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_Gnu__241$vtype	*vtype;
	_jc_gnu_java_security_provider_Gnu__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_Gnu__241$vtype _jc_gnu_java_security_provider_Gnu__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_Gnu__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_Gnu__241$class_object;

#endif	/* _JC_gnu_java_security_provider_Gnu__241_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/Gnu__241.h <==
// final class gnu.java.security.provider.Gnu$1

// class file dependencies
// @dep_class f0178e05dba8a608 gnu_java_security_provider_Gnu__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_Gnu__241_H_
#define _JC_gnu_java_security_provider_Gnu__241_H_

// Forward structure declarations
struct _jc_gnu_java_security_provider_Gnu$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_Gnu__241$sub_refs	_jc_gnu_java_security_provider_Gnu__241$sub_refs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs	_jc_gnu_java_security_provider_Gnu__241$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$refs	_jc_gnu_java_security_provider_Gnu__241$refs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$nonrefs	_jc_gnu_java_security_provider_Gnu__241$nonrefs;
typedef struct _jc_gnu_java_security_provider_Gnu__241$object	_jc_gnu_java_security_provider_Gnu__241$object;

typedef const struct _jc_gnu_java_security_provider_Gnu__241$vmethods	_jc_gnu_java_security_provider_Gnu__241$vmethods;
typedef const struct _jc_gnu_java_security_provider_Gnu__241$vtable	_jc_gnu_java_security_provider_Gnu__241$vtable;
typedef const struct _jc_gnu_java_security_provider_Gnu__241$vtype	_jc_gnu_java_security_provider_Gnu__241$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_Gnu__241$method$_init$0939e4b1125759da(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *, struct _jc_gnu_java_security_provider_Gnu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_provider_Gnu__241$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_Gnu__241$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_security_provider_Gnu__241$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_provider_Gnu__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_Gnu__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_Gnu__241$vmethods	gnu_java_security_provider_Gnu__241;
};

// Vtype
struct _jc_gnu_java_security_provider_Gnu__241$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_Gnu__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu__241$sub_refs {
	struct _jc_gnu_java_security_provider_Gnu$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu__241$refs {
    _jc_gnu_java_security_provider_Gnu__241$sub_refs	gnu_java_security_provider_Gnu__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_Gnu__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_Gnu__241$sub_nonrefs	gnu_java_security_provider_Gnu__241;
};

// Object instance structure
struct _jc_gnu_java_security_provider_Gnu__241$object {
	_jc_gnu_java_security_provider_Gnu__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_Gnu__241$vtype	*vtype;
	_jc_gnu_java_security_provider_Gnu__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_Gnu__241$vtype _jc_gnu_java_security_provider_Gnu__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_Gnu__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_Gnu__241$class_object;

#endif	/* _JC_gnu_java_security_provider_Gnu__241_H_ */
